package net.knarcraft.permissionsigns.command;

import net.knarcraft.permissionsigns.PermissionSigns;
import net.knarcraft.permissionsigns.container.PermissionSign;
import net.knarcraft.permissionsigns.formatting.TranslatableMessage;
import net.knarcraft.permissionsigns.formatting.Translator;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;
import org.jetbrains.annotations.NotNull;

import java.util.List;

/**
 * The command used to create a new permission sign
 */
public class CreateCommand implements CommandExecutor {

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label, @NotNull String[] args) {
        // /ps create <name> <permission,permission> <cost> <duration> to create a new permission-sign
        //Name and permission(s) required, but duration and cost optional
        if (!(sender instanceof Player)) {
            sender.sendMessage(Translator.getTranslatedMessage(TranslatableMessage.COMMAND_PLAYER_ONLY));
            return false;
        }
        if (args.length < 2) {
            sender.sendMessage(Translator.getTranslatedMessage(TranslatableMessage.MISSING_CREATION_INFO));
            return false;
        }

        String name = args[0];
        String[] permissions = args[1].split(",");
        int cost;
        int duration;
        try {
            cost = Integer.parseInt(args[2]);
        } catch (NumberFormatException exception) {
            sender.sendMessage(Translator.getTranslatedMessage(TranslatableMessage.COST_INVALID_NUMBER));
            return false;
        }
        try {
            duration = Integer.parseInt(args[3]);
        } catch (NumberFormatException exception) {
            sender.sendMessage(Translator.getTranslatedMessage(TranslatableMessage.DURATION_INVALID_NUMBER));
            return false;
        }

        PermissionSign newSign = new PermissionSign(name, List.of(permissions), cost, duration);
        PermissionSigns.addSignCreationRequest((Player) sender, newSign);
        return true;
    }

}
